@@ -1,3 +1,4 @@
+import os
 import sys
 from pathlib import Path
 
@@ -17,6 +18,8 @@ def generate(config_path: Path):
     Logger.log_info("Loading Config")
     config = setup_settings(config_path)
     managers = (PageManager, StaticManager, MetaManager)
+    parent_folder = config_path.resolve().parent
+    os.chdir(str(parent_folder))
     Logger.log_info("Setting Up")
     gen = SiteGen(config, managers)
     Logger.log_info("Beginning Generation")
@@ -26,6 +29,8 @@ def generate(config_path: Path):
     gen.initialize()
     Logger.log_info("Generating Content")
     gen.generate()
+    if gen.settings['cache_enabled']:
+        gen.cache.dump()
     Logger.log_info("Done!")
 
 
